@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12834 2021-04-08 03:24:09Z Casey $
+# $Id: __init__.py 12806 2021-03-24 05:59:30Z Casey $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Casey $ (last)
-# $Date: 2021-04-08 11:24:09 +0800 (Thu, 08 Apr 2021) $
-# $Revision: 12834 $
+# $Date: 2021-03-24 13:59:30 +0800 (Wed, 24 Mar 2021) $
+# $Revision: 12806 $
 
 from __future__ import print_function
 
@@ -857,8 +857,6 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
             'IUNO_MEMBER_GMAIL_LOGIN_ENABLE': False,
             'IUNO_MEMBER_YAHOO_LOGIN_ENABLE': False,
             'IUNO_MEMBER_MSN_LIVE_LOGIN_ENABLE': False,
-            'IUNO_MEMBER_ACCOUNT_LOCALE_ENABLE': False,
-            'IUNO_MEMBER_ACCOUNT_TIMEZONE_ENABLE': False,
         }
 
         update(settingsDict, iunoMemberDefaults)
@@ -872,9 +870,7 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
                             settingsDict['IUNO_MEMBER_FACEBOOK_LOGIN_ENABLE'],
                             settingsDict['IUNO_MEMBER_GMAIL_LOGIN_ENABLE'],
                             settingsDict['IUNO_MEMBER_MSN_LIVE_LOGIN_ENABLE'],
-                            settingsDict['IUNO_MEMBER_YAHOO_LOGIN_ENABLE'],
-                            settingsDict['IUNO_MEMBER_ACCOUNT_LOCALE_ENABLE'],
-                            settingsDict['IUNO_MEMBER_ACCOUNT_LOCALE_ENABLE']
+                            settingsDict['IUNO_MEMBER_YAHOO_LOGIN_ENABLE']
                         )
         else: # IUNO_MEMBER_ENABLE = False
             if warns:
@@ -1057,19 +1053,6 @@ def attachURLs(settings, urlpatterns):
         url(r'^django-des/', include(des_urls)),
     )
 
-    #==========================================================================
-    # Iuno.member.
-    try:
-        module = checkImportPackageForAttachURLs('Iuno.member')
-    except ImportError:
-        pass
-    else:
-        if module:
-            import Iuno.member
-
-    if getattr(settings, 'IUNO_MEMBER_ENABLE', None) and module:
-        Iuno.member.attachURLs(settings, urlpatterns)
-
     #=========================================================================
     # Iuno.cloud.
     try:
@@ -1087,19 +1070,6 @@ def attachURLs(settings, urlpatterns):
 
         Iuno.cloud.attachURLs(settings, urlpatterns, **attachCloudKws)
 
-    #==========================================================================
-    # Iuno.shop.
-    try:
-        module = checkImportPackageForAttachURLs('Iuno.shop')
-    except ImportError:
-        pass
-    else:
-        if module:
-            import Iuno.shop
-
-    if getattr(settings, 'IUNO_SHOP_ENABLE', None) and module:
-        Iuno.shop.attachURLs(settings, urlpatterns)
-        
     #==========================================================================
     # Iuno.test.
     addTestUrl = False
@@ -1127,4 +1097,27 @@ def attachURLs(settings, urlpatterns):
                 })
             )
 
+    #==========================================================================
+    # Iuno.shop.
+    try:
+        module = checkImportPackageForAttachURLs('Iuno.shop')
+    except ImportError:
+        pass
+    else:
+        if module:
+            import Iuno.shop
 
+    if getattr(settings, 'IUNO_SHOP_ENABLE', None) and module:
+        Iuno.shop.attachURLs(settings, urlpatterns)
+    #==========================================================================
+    # Iuno.member.
+    try:
+        module = checkImportPackageForAttachURLs('Iuno.member')
+    except ImportError:
+        pass
+    else:
+        if module:
+            import Iuno.member
+
+    if getattr(settings, 'IUNO_MEMBER_ENABLE', None) and module:
+        Iuno.member.attachURLs(settings, urlpatterns)
