@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12833 2021-04-08 03:09:01Z Casey $
+# $Id: __init__.py 12806 2021-03-24 05:59:30Z Casey $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Casey $ (last)
-# $Date: 2021-04-08 11:09:01 +0800 (Thu, 08 Apr 2021) $
-# $Revision: 12833 $
+# $Date: 2021-03-24 13:59:30 +0800 (Wed, 24 Mar 2021) $
+# $Revision: 12806 $
 
 import os
 import sys
@@ -49,22 +49,10 @@ def attachSettings(settingsDict, enableFacebook=False, enableGoogle=False,
         'django.contrib.sites',
     )
 
-    if enableLocale and not enableTimezone:
-        ADDING_MIDDLEWARE_CLASSES = (
-            'account.middleware.LocaleMiddleware',
-        )
-    elif not enableLocale and enableTimezone:
-        ADDING_MIDDLEWARE_CLASSES = (
-            'account.middleware.TimezoneMiddleware',
-        )
-    elif enableLocale and enableTimezone:
-        ADDING_MIDDLEWARE_CLASSES = (
-            'account.middleware.LocaleMiddleware',
-            'account.middleware.TimezoneMiddleware',
-        )
-    else:
-        # 皆不要
-        ADDING_MIDDLEWARE_CLASSES = ()
+    ADDING_MIDDLEWARE_CLASSES = (
+        'account.middleware.LocaleMiddleware',
+        'account.middleware.TimezoneMiddleware',
+    )
 
     installed = settingsDict['INSTALLED_APPS']
     keys = [k for k in installed if k.startswith('django.contrib')]
@@ -72,7 +60,7 @@ def attachSettings(settingsDict, enableFacebook=False, enableGoogle=False,
                         key=list(keys)[-1])
 
     extendMiddlewareClasses(settingsDict, ADDING_MIDDLEWARE_CLASSES,
-                            key='django.contrib.auth.middleware.AuthenticationMiddleware')
+                            key='django.middleware.security.SecurityMiddleware')
     #=========================================================================
 
     #=========================================================================
@@ -230,6 +218,23 @@ def attachSettings(settingsDict, enableFacebook=False, enableGoogle=False,
 def attachURLs(settings, urlpatterns):
     from django.conf.urls import include, url
 
-    urlpatterns += (
-        url(r'accounts/', include('Iuno.member.urls')),
+    from .views import (
+        SignupView, LoginView, ConfirmEmailView, ChangePasswordView, LogoutView,
+        PasswordResetView, PasswordResetTokenView, SettingsView, DeleteView
+    )
+
+    urlpatterns += patterns(
+        url(r"^signup/$", SignupView.as_view(), name="account_signup"),
+        url(r"^login/$", LoginView.as_view(), name="account_login"),
+        url(r"^logout/$", LogoutView.as_view(), name="account_logout"),
+        url(r"^confirm_email/(?P<key>\w+)/$",
+            ConfirmEmailView.as_view(), name="account_confirm_email"),
+        url(r"^password/$", ChangePasswordView.as_view(), name="account_password"),
+        url(r"^password/reset/$", PasswordResetView.as_view(),
+            name="account_password_reset"),
+        url(r"^password/reset/(?P<uidb36>[0-9A-Za-z]+)-(?P<token>.+)/$",
+            PasswordResetTokenView.as_view(), name="account_password_reset_token"),
+        url(r"^settings/$", SettingsView.as_view(), name="account_settings"),
+        url(r"^delete/$", DeleteView.as_view(), name="account_delete"),
+        url('', include('social_django.urls', namespace='social')),
     )
